const PRIMES: &[u8] = include_bytes!("primes.32b"); // http://www.umopit.ru/CompLab/primes32.htm
const NUM_PRIMES: usize = PRIMES.len() / 4;
const LAST: u32 = prime_at(NUM_PRIMES - 1);

const fn prime_at(index: usize) -> u32 {
    u32::from_le_bytes([
        PRIMES[index * 4],
        PRIMES[index * 4 + 1],
        PRIMES[index * 4 + 2],
        PRIMES[index * 4 + 3],
    ])
}

pub fn entry(num: u32) -> bool {
    if num < 2 {
        false
    } else if num == 2 {
        true
    } else if num > LAST {
        false
    } else {
        let mut lo = 0;
        let mut hi = NUM_PRIMES - 1;
        let mut isp = false;
        while lo <= hi {
            let guess = lo + (hi - lo) / 2;
            let p = prime_at(guess);
            use std::cmp::Ordering::*;
            match num.cmp(&p) {
                Equal => {
                    isp = true;
                    break;
                }
                Less => hi = guess - 1,
                Greater => lo = guess + 1,
            }
        }
        isp
    }
}
